@@ -3,6 +3,7 @@ from os import chdir
 from .client.functions import FunctionCollection, keys
 from .client.globals import Globals, GlobalVar
 from .client.hints import Function, Key, SkillCode, SkillList, SkillTuple, Symbol
+from .client.objects import LazyList, RemoteObject, RemoteTable, RemoteVector
 from .client.translator import ParseError
 from .client.var import Var
 from .client.workspace import Workspace, current_workspace
@@ -25,6 +26,10 @@ __all__ = [
     'loop_var_j',
     'Globals',
     'GlobalVar',
+    'RemoteTable',
+    'RemoteVector',
+    'RemoteObject',
+    'LazyList',
 ]
 
 loop_var = Var('i')
